High-Level Visualizations
=========================

Heatmap Variants
----------------

.. currentmodule:: heatgraphy
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Heatmap
    SizedHeatmap
    CatHeatmap

Layers Heatmap
--------------

.. currentmodule:: heatgraphy.layers
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Layers
    LayersMesh
    Rect
    FrameRect
    FracRect
    Piece

UpSet plots
-----------

.. currentmodule:: heatgraphy.upset
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Upset
    UpsetData

Customized elements
-------------------

.. currentmodule:: heatgraphy.layers
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Layers
    Piece
